api.eventfilters.v1 package — Argus-Toolbelt 1.0 documentation

# api.eventfilters.v1 package

## Submodules

## api.eventfilters.v1.filter module

Autogenerated API

`api.eventfilters.v1.filter.` `error_stats`(includeDetails: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch filter error statistics (INTERNAL)

  Return type: | `dict`
  Parameters: | includeDetails (bool) – If true, include detailed error statistics per processing node
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {}

`api.eventfilters.v1.filter.` `get`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch filter (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of filter to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 845, “limit”: 222, “responseCode”: 200, “count”: 556, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Reach produce these pay party themselves.”, “messageTemplate”: “Decide democratic teacher exist late above fill bag.”, “field”: “Election various hold discuss during officer.”, “parameter”: {}, “timestamp”: 796347506}], “currentPage”: 332, “size”: 977}

`api.eventfilters.v1.filter.` `hit_stats`(period: int = 3600000, includeDetails: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch filter error statistics (INTERNAL)

  Return type: | `dict`
  Parameters: | period (int) – Time period to fetch hit stats for (milliseconds) includeDetails (bool) – If true, include details about hits per processing node
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {}

`api.eventfilters.v1.filter.` `list`(search: str = None, customerID: list = None, type: str = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List filters (INTERNAL)

  Return type: | `dict`
  Parameters: | search (str) – Limit result to filters matching this searchstring customerID (list) – Limit result to filters for this customerID type (str) – Limit result to filters of this type limit (int) – Limit result offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 622, “limit”: 546, “responseCode”: 200, “count”: 477, “data”: [{“revision”: 633, “deleted”: true, “information”: “Move describe speech instead security structure fall.”, “masterID”: 467, “expired”: false, “valid”: false, “enabled”: false, “index”: 564, “flags”: 797, “labels”: [“During live without ground rock.”], “description”: “Too memory benefit.”, “id”: 431, “lastUpdatedTimestamp”: 830167045, “validFromTimestamp”: 1439347248, “validToTimestamp”: 1014671162, “lastUpdatedByUser”: {“id”: 184, “customerID”: 113, “userName”: “smithdustin”, “name”: “Tyler Grant”}, “createdTimestamp”: 436404805}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Front store them second its agency model.”, “messageTemplate”: “Wish hour expert rise true.”, “field”: “Keep you size box mention season high.”, “parameter”: {}, “timestamp”: 486384201}], “currentPage”: 912, “size”: 17}

`api.eventfilters.v1.filter.` `revisions`(id: int, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch filter revisions by filter ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – Fetch revisions for filter with this ID limit (int) – Limit result offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 483, “limit”: 692, “responseCode”: 200, “count”: 462, “data”: [{“revision”: 344, “deleted”: true, “information”: “Growth others population.”, “masterID”: 221, “expired”: false, “valid”: false, “enabled”: false, “index”: 123, “flags”: 888, “labels”: [“Cover society brother about brother recently better.”], “description”: “Soon son plan join then sing.”, “id”: 106, “lastUpdatedTimestamp”: 1410962745, “validFromTimestamp”: 851000157, “validToTimestamp”: 1155690561, “lastUpdatedByUser”: {“id”: 426, “customerID”: 249, “userName”: “james14”, “name”: “Natalie Walker”}, “createdTimestamp”: 86129423}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Suffer recently international end oil.”, “messageTemplate”: “Expect view improve record book natural health.”, “field”: “Western front once night back career quite.”, “parameter”: {}, “timestamp”: 363320766}], “currentPage”: 421, “size”: 311}

`api.eventfilters.v1.filter.` `search`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, customerID: <function list at 0x10f160400> = None, type: str = None, description: str = None, searchString: str = None, labels: <function list at 0x10f160400> = None, masterID: int = None, userID: <function list at 0x10f160400> = None, filterID: <function list at 0x10f160400> = None, associatedCaseID: <function list at 0x10f160400> = None, hitPeriod: int = None, minimumHits: int = None, maximumHits: int = None, sortBy: <function list at 0x10f160400> = None, startTimestamp: int = None, endTimestamp: int = None, subCriteria: <function list at 0x10f160400> = None, includeDeleted: bool = 'False', includeCreatedTimestamp: bool = 'False', includeLastUpdatedTimestamp: bool = 'False', excludeExpired: bool = 'False', excludeFuture: bool = 'False', excludeValid: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search filters (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results includeFlags (int) – Search objects with these flags set excludeFlags (int) – Exclude objects with these flags set customerID (list) – Limit result to objects belonging to these customers type (str) – Limit search to filters of this type description (str) – Match filters by words in description searchString (str) – Match filters by words in entire filter configuration labels (list) – Limit search to filters with any of these filters masterID (int) – Limit search to revisions of this master ID (by default, revisions are excluded) userID (list) – Limit search to filters created/updated by any of these users filterID (list) – Limit search to these spesific filters associatedCaseID (list) – Limit search to filters associated to any of the listed cases. AssociatedCaseID 0 will include filters not associated to a case. hitPeriod (int) – When searching by filter hits, look at hits for this period (previous time period in milliseconds) minimumHits (int) – Limit search to filters reporting at least this number of hits for the hit period (SLOW) maximumHits (int) – Limit search to filters reporting at most this number of hits for the hit period (SLOW) sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp subCriteria (list) – includeDeleted (bool) – Also include deleted objects (where implemented) includeCreatedTimestamp (bool) – When limiting filters by time, include filters by created timestamp includeLastUpdatedTimestamp (bool) – When limiting filters by time, include filters by last updated timestamp excludeExpired (bool) – Exclude filters which are expired (validToTimestamp has passed) excludeFuture (bool) – Exclude filters which are not yet active (validFromTimestamp is in the future) excludeValid (bool) – Exclude filters which are currently valid
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 446, “limit”: 647, “responseCode”: 200, “count”: 658, “data”: [{“revision”: 896, “deleted”: false, “information”: “Up international cell society discover.”, “masterID”: 765, “expired”: false, “valid”: false, “enabled”: true, “index”: 436, “flags”: 103, “labels”: [“She often win current.”], “description”: “Accept mention tax land product side might.”, “id”: 883, “lastUpdatedTimestamp”: 264008466, “validFromTimestamp”: 532162318, “validToTimestamp”: 665391918, “lastUpdatedByUser”: {“id”: 611, “customerID”: 490, “userName”: “zdecker”, “name”: “Tammy Tucker”}, “createdTimestamp”: 582131075}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Kind drive remain clear or front.”, “messageTemplate”: “Financial these budget tough girl.”, “field”: “System contain modern indeed.”, “parameter”: {}, “timestamp”: 1234333055}], “currentPage”: 273, “size”: 224}

`api.eventfilters.v1.filter.` `set_log_level`(id: int, level: str = None, instanceID: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Set log level for specified filter (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of event filter level (str) – Log level to be set for event filter instanceID (int) – ID of component instance to set log level for event filter, if not provided will set across instances
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404 OperationTimeoutException – on 408
  Returns: | {}

## Module contents